@@ -132,16 +132,15 @@ void test_builtin_get(void){
 
 /*
 ** Input zList is a list of numeric identifiers for files in
-** aBuiltinFiles[].  Return the concatenation of all of those
-** files using mimetype zType, or as application/javascript if
-** zType is 0.
+** aBuiltinFiles[].  Return the concatenation of all of those files
+** using mimetype zType, or as text/javascript if zType is 0.
 */
 static void builtin_deliver_multiple_js_files(
   const char *zList,   /* List of numeric identifiers */
   const char *zType    /* Override mimetype */
 ){
   Blob *pOut;
-  if( zType==0 ) zType = "application/javascript";
+  if( zType==0 ) zType = "text/javascript";
   cgi_set_content_type(zType);
   pOut = cgi_output_blob();
   while( zList[0] ){
@@ -158,7 +157,7 @@ static void builtin_deliver_multiple_js_files(
 }
 
 /*
-** WEBPAGE: builtin
+** WEBPAGE: builtin loadavg-exempt
 **
 ** Return one of many built-in content files.  Query parameters:
 **
@@ -205,7 +204,7 @@ void builtin_webpage(void){
   }
   if( zType==0 ){
     if( sqlite3_strglob("*.js", zName)==0 ){
-      zType = "application/javascript";
+      zType = "text/javascript";
     }else{
       zType = mimetype_from_name(zName);
     }
@@ -233,6 +232,8 @@ static struct {
 
 #if INTERFACE
 /* Various delivery mechanisms.  The 0 option is the default.
+** MAINTENANCE NOTE: Review/update the builtin_set_js_delivery_mode() and
+** builtin_get_js_delivery_mode_name() functions if values are changed/added.
 */
 #define JS_INLINE   0    /* inline, batched together at end of file */
 #define JS_SEPARATE 1    /* Separate HTTP request for each JS file */
@@ -271,6 +272,26 @@ int builtin_get_js_delivery_mode(void){
   return builtin.eDelivery;
 }
 
+/*
+** Returns the name of the current JS delivery mode for reuse with the --jsmode
+** option, i.e. the other way around than builtin_set_js_delivery_mode().
+*/
+const char *builtin_get_js_delivery_mode_name(void){
+  switch( builtin.eDelivery ){
+    case JS_SEPARATE: {
+      return "separate";
+    }
+    case JS_BUNDLED: {
+      return "bundled";
+    }
+    case JS_INLINE:
+      /*FALLTHROUGH*/
+    default: {
+      return "inline";
+    }
+  }
+}
+
 /*
 ** The caller wants the Javascript file named by zFilename to be
 ** included in the generated page.  Add the file to the queue of
