@@ -130,7 +130,7 @@ static void chat_emit_alert_list(void){
 ** The value must be the name of a builtin WAV file.
 */
 /*
-** WEBPAGE: chat
+** WEBPAGE: chat loadavg-exempt
 **
 ** Start up a browser-based chat session.
 **
@@ -237,7 +237,8 @@ void chat_webpage(void){
   fossil_free(zProjectName);
   fossil_free(zInputPlaceholder0);
   builtin_fossil_js_bundle_or("popupwidget", "storage", "fetch",
-                              "pikchr", "confirmer", NULL);
+                              "pikchr", "confirmer", "copybutton",
+                              NULL);
   /* Always in-line the javascript for the chat page */
   @ <script nonce="%h(style_nonce())">/* chat.c:%d(__LINE__) */
   /* We need an onload handler to ensure that window.fossil is
@@ -344,7 +345,7 @@ static void chat_emit_permissions_error(int fAsMessageList){
 }
 
 /*
-** WEBPAGE: chat-send hidden
+** WEBPAGE: chat-send hidden loadavg-exempt
 **
 ** This page receives (via XHR) a new chat-message and/or a new file
 ** to be entered into the chat history.
@@ -450,7 +451,7 @@ void chat_test_formatter_cmd(void){
 }
 
 /*
-** WEBPAGE: chat-poll hidden
+** WEBPAGE: chat-poll hidden loadavg-exempt
 **
 ** The chat page generated by /chat using an XHR to this page to
 ** request new chat content.  A typical invocation is:
@@ -669,7 +670,7 @@ void chat_poll_webpage(void){
 }
 
 /*
-** WEBPAGE: chat-fetch-one hidden
+** WEBPAGE: chat-fetch-one hidden loadavg-exempt
 **
 ** /chat-fetch-one/N
 **
@@ -746,7 +747,7 @@ void chat_fetch_one(void){
 }
 
 /*
-** WEBPAGE: chat-download hidden
+** WEBPAGE: chat-download hidden loadavg-exempt
 **
 ** Download the CHAT.FILE attachment associated with a single chat
 ** entry.  The "name" query parameter begins with an integer that
@@ -779,7 +780,7 @@ void chat_download_webpage(void){
 
 
 /*
-** WEBPAGE: chat-delete hidden
+** WEBPAGE: chat-delete hidden loadavg-exempt
 **
 ** Delete the chat entry identified by the name query parameter.
 ** Invoking fetch("chat-delete/"+msgid) from javascript in the client
