@@ -40,7 +40,7 @@
 
 #if INTERFACE
 
-/* Many APIs take a eFType argument which must be one of ExtFILE, RepoFILE,
+/* Many APIs take an eFType argument which must be one of ExtFILE, RepoFILE,
 ** or SymFILE.
 **
 ** The difference is in the handling of symbolic links.  RepoFILE should be
@@ -1194,10 +1194,9 @@ void cmd_test_simplify_name(void){
 ** or if zBuf==0, allocate space to hold the result using fossil_malloc().
 */
 char *file_getcwd(char *zBuf, int nBuf){
-  char zTemp[2000];
   if( zBuf==0 ){
-    zBuf = zTemp;
-    nBuf = sizeof(zTemp);
+    char zTemp[2000];
+    return fossil_strdup(file_getcwd(zTemp, sizeof(zTemp)));
   }
 #ifdef _WIN32
   win32_getcwd(zBuf, nBuf);
@@ -1211,7 +1210,7 @@ char *file_getcwd(char *zBuf, int nBuf){
     }
   }
 #endif
-  return zBuf==zTemp ? fossil_strdup(zBuf) : zBuf;
+  return zBuf;
 }
 
 /*
@@ -1297,9 +1296,6 @@ char *file_canonical_name_dup(const char *zOrigName){
 ** type on a command-line.  This routine resolves that name into
 ** a full pathname.  The result is obtained from fossil_malloc()
 ** and should be freed by the caller.
-**
-** This routine only works on unix.  On Windows, simply return
-** a copy of the input.
 */
 char *file_fullexename(const char *zCmd){
 #ifdef _WIN32
