@@ -159,22 +159,29 @@ int start_of_branch(int rid, int eType){
   int ans = rid;
   char *zBr = branch_of_rid(rid);
   db_prepare(&q,
-    "SELECT pid, EXISTS(SELECT 1 FROM tagxref"
-                       " WHERE tagid=%d AND tagtype>0"
-                       "   AND value=%Q AND rid=plink.pid)"
-    "  FROM plink"
-    " WHERE cid=:cid AND isprim",
-    TAG_BRANCH, zBr
+    "WITH RECURSIVE"
+    "  par(pid, ex, cnt) as ("
+    "    SELECT pid, EXISTS(SELECT 1 FROM tagxref"
+    "                        WHERE tagid=%d AND tagtype>0"
+    "                          AND value=%Q AND rid=plink.pid), 1"
+    "    FROM plink WHERE cid=%d AND isprim"
+    "    UNION ALL "
+    "    SELECT plink.pid, EXISTS(SELECT 1 FROM tagxref "
+    "                              WHERE tagid=%d AND tagtype>0" 
+    "                                AND value=%Q AND rid=plink.pid),"
+    "           1+par.cnt"
+    "      FROM plink, par"
+    "     WHERE cid=par.pid AND isprim AND par.ex "
+    "     LIMIT 100000 "
+    "  )"
+    " SELECT pid FROM par WHERE ex>=%d ORDER BY cnt DESC LIMIT 1",
+    TAG_BRANCH, zBr, ans, TAG_BRANCH, zBr, eType%2
   );
   fossil_free(zBr);
-  do{
-    db_reset(&q);
-    db_bind_int(&q, ":cid", ans);
-    rc = db_step(&q);
-    if( rc!=SQLITE_ROW ) break;
-    if( eType==1 && db_column_int(&q,1)==0 ) break;
+  rc = db_step(&q);
+  if( rc==SQLITE_ROW ){ 
     ans = db_column_int(&q, 0);
-  }while( db_column_int(&q, 1)==1 && ans>0 );
+  }
   db_finalize(&q);
   if( eType==2 && ans>0 ){
     zBr = branch_of_rid(ans);
@@ -239,7 +246,7 @@ static int is_trailing_punct(char c){
 ** Convert a symbolic name into a RID.  Acceptable forms:
 **
 **   *  artifact hash (optionally enclosed in [...])
-**   *  4-character or larger prefix of a artifact
+**   *  4-character or larger prefix of an artifact
 **   *  Symbolic Name
 **   *  "tag:" + symbolic name
 **   *  Date or date-time
@@ -256,6 +263,7 @@ static int is_trailing_punct(char c){
 ** The following modifier prefixes may be applied to the above forms:
 **
 **   *  "root:BR" = The origin of the branch named BR.
+**   *  "start:BR" = The first check-in of the branch named BR.
 **   *  "merge-in:BR" = The most recent merge-in for the branch named BR.
 **
 ** In those forms, BR may be any symbolic form but is assumed to be a
@@ -373,7 +381,14 @@ int symbolic_name_to_rid(const char *zTag, const char *zType){
     rid = symbolic_name_to_rid(zTag+5, zType);
     return start_of_branch(rid, 0);
   }
-  /* merge-in:BR -> Most recent merge-in for the branch name BR */
+
+  /* start:BR -> The first check-in on branch named BR */
+  if( strncmp(zTag, "start:", 6)==0 ){
+    rid = symbolic_name_to_rid(zTag+6, zType);
+    return start_of_branch(rid, 1);
+  }  
+  
+  /* merge-in:BR -> Most recent merge-in for the branch named BR */
   if( strncmp(zTag, "merge-in:", 9)==0 ){
     rid = symbolic_name_to_rid(zTag+9, zType);
     return start_of_branch(rid, 2);
@@ -553,7 +568,7 @@ int name_to_uuid(Blob *pName, int iErrPriority, const char *zType){
     fossil_error(iErrPriority, "ambiguous name: %s", zName);
     return 2;
   }else if( rid==0 ){
-    fossil_error(iErrPriority, "not found: %s", zName);
+    fossil_error(iErrPriority, "cannot resolve name: %s", zName);
     return 1;
   }else{
     blob_reset(pName);
@@ -663,7 +678,7 @@ int name_to_typed_rid(const char *zName, const char *zType){
   if( rid<0 ){
     fossil_fatal("ambiguous name: %s", zName);
   }else if( rid==0 ){
-    fossil_fatal("not found: %s", zName);
+    fossil_fatal("cannot resolve name: %s", zName);
   }
   return rid;
 }
@@ -1738,7 +1753,7 @@ void test_phatoms_cmd(void){
 ** generated by the SQL given in the argument.
 */
 static void collision_report(const char *zSql){
-  int i, j, kk;
+  int i, j;
   int nHash = 0;
   Stmt q;
   char zPrev[HNAME_MAX+1];
@@ -1775,11 +1790,9 @@ static void collision_report(const char *zSql){
   }
   @ </tbody></table>
   @ <p>Total number of hashes: %d(nHash)</p>
-  kk = 0;
   for(i=HNAME_MAX; i>=4; i--){
     if( aCollide[i].cnt==0 ) continue;
     if( aCollide[i].cnt>200 ) break;
-    kk += aCollide[i].cnt;
     if( aCollide[i].cnt<25 ){
       @ <p>Collisions of length %d(i):
     }else{
