@@ -362,7 +362,7 @@ static void addAutoHyperlinkSettings(void){
   @ <p>The "UserAgent and Javascript" value for this setting provides
   @ superior protection from robots.  However, that setting also prevents
   @ the visited/unvisited colors on hyperlinks from displaying correctly
-  @ on Safara-derived browsers.  (Chrome and Firefox work fine.)  Since
+  @ on Safari-derived browsers.  (Chrome and Firefox work fine.)  Since
   @ Safari is the underlying rendering engine on all iPhones and iPads,
   @ this means that hyperlink visited/unvisited colors will not operate
   @ on those platforms when "UserAgent and Javascript" is selected.</p>
@@ -1033,7 +1033,7 @@ void setup_settings(void){
 **       repository root.
 **
 **   *   The third term is an argument to the TH1 "capexpr" command.
-**       If capexpr evalutes to true, then the entry is shown.  If not,
+**       If capexpr evaluates to true, then the entry is shown.  If not,
 **       the entry is omitted.  "*" is always true.  "{}" is never true.
 **
 **   *   The fourth term is a list of extra class names to apply to the
@@ -1064,7 +1064,7 @@ void setup_settings(void){
 **       repository root.
 **
 **   *   The third term is an argument to the TH1 "capexpr" command.
-**       If capexpr evalutes to true, then the entry is shown.  If not,
+**       If capexpr evaluates to true, then the entry is shown.  If not,
 **       the entry is omitted.  "*" is always true.
 **
 ** The default value is blank, meaning no added entries.
@@ -1164,7 +1164,7 @@ void setup_config(void){
   @      entry.  Hyperlinks that start with "/" are relative to the
   @      repository root.
   @ <li> The third term is an argument to the TH1 "capexpr" command.
-  @      If capexpr evalutes to true, then the entry is shown.  If not,
+  @      If capexpr evaluates to true, then the entry is shown.  If not,
   @      the entry is omitted.  "*" is always true.  "{}" is never true.
   @ <li> The fourth term is a list of extra class names to apply to the new
   @      menu entry.  Some skins use classes "desktoponly" and "wideonly"
@@ -1202,7 +1202,7 @@ void setup_config(void){
   @      entry.  Hyperlinks that start with "/" are relative to the
   @      repository root.
   @ <li> The third term is an argument to the TH1 "capexpr" command.
-  @      If capexpr evalutes to true, then the entry is shown.  If not,
+  @      If capexpr evaluates to true, then the entry is shown.  If not,
   @      the entry is omitted.  "*" is always true.
   @ </ol>
   @
