@@ -25,7 +25,7 @@
 /*
 ** The list of database user-defined fields in the TICKET table.
 ** The real table also contains some addition fields for internal
-** used.  The internal-use fields begin with "tkt_".
+** use.  The internal-use fields begin with "tkt_".
 */
 static int nField = 0;
 static struct tktFieldInfo {
@@ -41,6 +41,10 @@ static u8 haveTicket = 0;        /* True if the TICKET table exists */
 static u8 haveTicketCTime = 0;   /* True if TICKET.TKT_CTIME exists */
 static u8 haveTicketChng = 0;    /* True if the TICKETCHNG table exists */
 static u8 haveTicketChngRid = 0; /* True if TICKETCHNG.TKT_RID exists */
+static u8 haveTicketChngUser = 0;/* True if TICKETCHNG.TKT_USER exists */
+static u8 useTicketGenMt = 0;    /* use generated TICKET.MIMETYPE */
+static u8 useTicketChngGenMt = 0;/* use generated TICKETCHNG.MIMETYPE */
+
 
 /*
 ** Compare two entries in aField[] for sorting purposes
@@ -71,7 +75,7 @@ static int fieldId(const char *zFieldName){
 */
 static void getAllTicketFields(void){
   Stmt q;
-  int i;
+  int i, noRegularMimetype;
   static int once = 0;
   if( once ) return;
   once = 1;
@@ -83,6 +87,7 @@ static void getAllTicketFields(void){
       if( strcmp(zFieldName, "tkt_ctime")==0 ) haveTicketCTime = 1;
       continue;
     }
+    if( strchr(zFieldName,' ')!=0 ) continue;
     if( nField%10==0 ){
       aField = fossil_realloc(aField, sizeof(aField[0])*(nField+10) );
     }
@@ -96,9 +101,14 @@ static void getAllTicketFields(void){
     const char *zFieldName = db_column_text(&q, 1);
     haveTicketChng = 1;
     if( memcmp(zFieldName,"tkt_",4)==0 ){
-      if( strcmp(zFieldName,"tkt_rid")==0 ) haveTicketChngRid = 1;
+      if( strcmp(zFieldName+4,"rid")==0 ){
+        haveTicketChngRid = 1;  /* tkt_rid */
+      }else if( strcmp(zFieldName+4,"user")==0 ){
+        haveTicketChngUser = 1; /* tkt_user */
+      }
       continue;
     }
+    if( strchr(zFieldName,' ')!=0 ) continue;
     if( (i = fieldId(zFieldName))>=0 ){
       aField[i].mUsed |= USEDBY_TICKETCHNG;
       continue;
@@ -112,9 +122,21 @@ static void getAllTicketFields(void){
   }
   db_finalize(&q);
   qsort(aField, nField, sizeof(aField[0]), nameCmpr);
+  noRegularMimetype = 1;
   for(i=0; i<nField; i++){
     aField[i].zValue = "";
     aField[i].zAppend = 0;
+    if( strcmp(aField[i].zName,"mimetype")==0 ){
+      noRegularMimetype = 0;
+    }
+  }
+  if( noRegularMimetype ){ /* check for generated "mimetype" columns */
+    useTicketGenMt = db_exists(
+      "SELECT 1 FROM pragma_table_xinfo('ticket') "
+      "WHERE name = 'mimetype'");
+    useTicketChngGenMt = db_exists(
+      "SELECT 1 FROM pragma_table_xinfo('ticketchng') "
+      "WHERE name = 'mimetype'");
   }
 }
 
@@ -191,12 +213,14 @@ static void initializeVariablesFromCGI(void){
 **
 ** Return the new rowid of the TICKET table entry.
 */
-static int ticket_insert(const Manifest *p, int rid, int tktid){
-  Blob sql1, sql2, sql3;
+static int ticket_insert(const Manifest *p, const int rid, int tktid){
+  Blob sql1; /* update or replace TICKET ... */
+  Blob sql2; /* list of TICKETCHNG's fields that are in the manifest */
+  Blob sql3; /* list of values which correspond to the previous list */
   Stmt q;
   int i, j;
   char *aUsed;
-  const char *zMimetype = 0;
+  int mimetype_tkt = MT_NONE, mimetype_tktchng = MT_NONE;
 
   if( tktid==0 ){
     db_multi_exec("INSERT INTO ticket(tkt_uuid, tkt_mtime) "
@@ -213,55 +237,56 @@ static int ticket_insert(const Manifest *p, int rid, int tktid){
   aUsed = fossil_malloc( nField );
   memset(aUsed, 0, nField);
   for(i=0; i<p->nField; i++){
-    const char *zName = p->aField[i].zName;
-    const char *zBaseName = zName[0]=='+' ? zName+1 : zName;
+    const char * const zName = p->aField[i].zName;
+    const char * const zBaseName = zName[0]=='+' ? zName+1 : zName;
     j = fieldId(zBaseName);
     if( j<0 ) continue;
     aUsed[j] = 1;
     if( aField[j].mUsed & USEDBY_TICKET ){
-      const char *zUsedByName = zName;
-      if( zUsedByName[0]=='+' ){
-        zUsedByName++;
+      if( zName[0]=='+' ){
         blob_append_sql(&sql1,", \"%w\"=coalesce(\"%w\",'') || %Q",
-                        zUsedByName, zUsedByName, p->aField[i].zValue);
+                        zBaseName, zBaseName, p->aField[i].zValue);
       }else{
-        blob_append_sql(&sql1,", \"%w\"=%Q", zUsedByName, p->aField[i].zValue);
+        blob_append_sql(&sql1,", \"%w\"=%Q", zBaseName, p->aField[i].zValue);
       }
     }
     if( aField[j].mUsed & USEDBY_TICKETCHNG ){
-      const char *zUsedByName = zName;
-      if( zUsedByName[0]=='+' ){
-        zUsedByName++;
-      }
-      blob_append_sql(&sql2, ",\"%w\"", zUsedByName);
+      blob_append_sql(&sql2, ",\"%w\"", zBaseName);
       blob_append_sql(&sql3, ",%Q", p->aField[i].zValue);
     }
     if( strcmp(zBaseName,"mimetype")==0 ){
-      zMimetype = p->aField[i].zValue;
-    }
-  }
-  if( rid>0 ){
-    for(i=0; i<p->nField; i++){
-      const char *zName = p->aField[i].zName;
-      const char *zBaseName = zName[0]=='+' ? zName+1 : zName;
-      j = fieldId(zBaseName);
-      if( j<0 ) continue;
-      backlink_extract(p->aField[i].zValue, zMimetype, rid, BKLNK_TICKET,
-                       p->rDate, i==0);
+      const char *zMimetype = p->aField[i].zValue;
+      /* "mimetype" is a regular column => these two flags must be 0 */
+      assert(!useTicketGenMt);
+      assert(!useTicketChngGenMt);
+      mimetype_tkt = mimetype_tktchng = parse_mimetype( zMimetype );
     }
   }
   blob_append_sql(&sql1, " WHERE tkt_id=%d", tktid);
+  if( useTicketGenMt ){
+    blob_append_literal(&sql1, " RETURNING mimetype");
+  }
   db_prepare(&q, "%s", blob_sql_text(&sql1));
   db_bind_double(&q, ":mtime", p->rDate);
   db_step(&q);
+  if( useTicketGenMt ){
+    mimetype_tkt = parse_mimetype( db_column_text(&q,0) );
+    if( !useTicketChngGenMt ){
+      mimetype_tktchng = mimetype_tkt;
+    }
+  }
   db_finalize(&q);
   blob_reset(&sql1);
-  if( blob_size(&sql2)>0 || haveTicketChngRid ){
+  if( blob_size(&sql2)>0 || haveTicketChngRid || haveTicketChngUser ){
     int fromTkt = 0;
     if( haveTicketChngRid ){
-      blob_append(&sql2, ",tkt_rid", -1);
+      blob_append_literal(&sql2, ",tkt_rid");
       blob_append_sql(&sql3, ",%d", rid);
     }
+    if( haveTicketChngUser && p->zUser ){
+      blob_append_literal(&sql2, ",tkt_user");
+      blob_append_sql(&sql3, ",%Q", p->zUser);
+    }
     for(i=0; i<nField; i++){
       if( aUsed[i]==0
        && (aField[i].mUsed & USEDBY_BOTH)==USEDBY_BOTH
@@ -275,21 +300,51 @@ static int ticket_insert(const Manifest *p, int rid, int tktid){
     }
     if( fromTkt ){
       db_prepare(&q, "INSERT INTO ticketchng(tkt_id,tkt_mtime%s)"
-                     "SELECT %d,:mtime%s FROM ticket WHERE tkt_id=%d",
+                     "SELECT %d,:mtime%s FROM ticket WHERE tkt_id=%d%s",
                      blob_sql_text(&sql2), tktid,
-                     blob_sql_text(&sql3), tktid);
+                     blob_sql_text(&sql3), tktid,
+                     useTicketChngGenMt ? " RETURNING mimetype" : "");
     }else{
       db_prepare(&q, "INSERT INTO ticketchng(tkt_id,tkt_mtime%s)"
-                     "VALUES(%d,:mtime%s)",
-                     blob_sql_text(&sql2), tktid, blob_sql_text(&sql3));
+                     "VALUES(%d,:mtime%s)%s",
+                     blob_sql_text(&sql2), tktid, blob_sql_text(&sql3),
+                     useTicketChngGenMt ? " RETURNING mimetype" : "");
     }
     db_bind_double(&q, ":mtime", p->rDate);
     db_step(&q);
+    if( useTicketChngGenMt ){
+      mimetype_tktchng = parse_mimetype( db_column_text(&q, 0) );
+      /* substitute NULL with a value generated within another table */
+      if( !useTicketGenMt ){
+        mimetype_tkt = mimetype_tktchng;
+      }else if( mimetype_tktchng==MT_NONE ){
+        mimetype_tktchng = mimetype_tkt;
+      }else if( mimetype_tkt==MT_NONE ){
+        mimetype_tkt = mimetype_tktchng;
+      }
+    }
     db_finalize(&q);
   }
   blob_reset(&sql2);
   blob_reset(&sql3);
   fossil_free(aUsed);
+  if( rid>0 ){                   /* extract backlinks */
+    int bReplace = 1, mimetype;
+    for(i=0; i<p->nField; i++){
+      const char *zName = p->aField[i].zName;
+      const char *zBaseName = zName[0]=='+' ? zName+1 : zName;
+      j = fieldId(zBaseName);
+      if( j<0 ) continue;
+      if( aField[j].mUsed & USEDBY_TICKETCHNG ){
+        mimetype = mimetype_tktchng;
+      }else{
+        mimetype = mimetype_tkt;
+      }
+      backlink_extract(p->aField[i].zValue, mimetype, rid, BKLNK_TICKET,
+                       p->rDate, bReplace);
+      bReplace = 0;
+    }
+  }
   return tktid;
 }
 
